class TechnologyTransfer
	include Mongoid::Document
	include Mongoid::Timestamps
	include OrbitModel::Status
  	include MemberHelper
  	include Slug

  	field :year, type: Integer
  	field :title,  as: :slug_title, type: String, localize: true
  	field :patent_granted, type: Boolean, default: false
  	field :patent_title, type: String, localize: true
  	field :patent_number


  	belongs_to :member_profile
  	belongs_to :technology_transfer_category

  	scope :sort_for_frontend, ->{ where(:is_hidden=>false).order_by(:year =>'desc') }

	def self.get_plugin_datas_to_member(datas)
		page = Page.where(:module => "personal_technology_transfer").first rescue nil
		
		if !page.nil? && !page.custom_array_field.blank?
			fields_to_show = page.custom_array_field
		else
		    fields_to_show = [
		      "category",
		      "year",
		      "title",
		      "patent_granted",
		      "patent_title",
		      "patent_number",
		      "authors"
		    ]
		end

	    fields_to_remove = []

    	pd_title = []

	    fields_to_show.each do |t|
	    	t = "technology_transfer_category" if t == "category"
	      if (self.fields[t].type.to_s == "String" || self.fields[t].type.to_s == "Object" rescue false)
	        fields_to_remove << t if (datas.where(t.to_sym.ne => nil, t.to_sym.ne => "").count == 0 rescue false)
	      else
	        fields_to_remove << t if (datas.where(t.to_sym.ne => nil).count == 0 rescue false)
	      end
	      pd_title <<  {
	          "plugin_data_title" => I18n.t("personal_technology_transfer.#{t}")
	        } if !fields_to_remove.include?(t)
	    end

	    fields_to_show = fields_to_show - fields_to_remove

	    plugin_datas = datas.sort_for_frontend.collect.with_index do |p,index|

	      pd_data = []
	      fields_to_show.collect do |t|
	        if t == "title"
	          	pd_data << { "data_title" => "<a href='#{OrbitHelper.url_to_plugin_show(p.to_param,'personal_technology_transfer')}' target='_blank'>#{p.send(t)}" }
	        elsif t == "category"
	          	pd_data << {"data_title" => (p.technology_transfer_category.title rescue "")}
	      	elsif t == "authors"
	      		pd_data << {"data_title" => (p.member_profile.name rescue "")}	
	      	elsif t == "patent_granted"
				pd_data << {"data_title" => (p.patent_granted ? I18n.t("personal_technology_transfer.y_es") : I18n.t("personal_technology_transfer.n_o"))}
	        else
	          pd_data << { "data_title" => p.send(t) }
	        end
	      end

	      {
	        "pd_datas" => pd_data,
	        "type-sort" => (p.technology_transfer_category.sort_position.to_i rescue 1000),
	        "sort-index" => index
	      }

	    end
	    plugin_datas = plugin_datas.sort_by{|pd| [pd["type-sort"], pd["sort-index"]]}
	    return [pd_title,plugin_datas]
	    
	end

	def get_plugin_data(fields_to_show)
	    plugin_datas = []
	    fields_to_show.each do |field|
	      plugin_data = self.get_plugin_field_data(field) rescue nil
	      next if plugin_data.blank? or plugin_data['value'].blank?
	      plugin_datas << plugin_data
	    end
	    plugin_datas
	end

  def get_plugin_field_data(field)
    case field
    when "technology_transfer_category", "category"
      	value = self.technology_transfer_category.title rescue ""
    when  "patent_granted"
    	value = self.patent_granted ? I18n.t("personal_technology_transfer.y_es") : I18n.t("personal_technology_transfer.n_o")
    else
      	value = self.send(field) rescue ""
    end

    value = (value =~ /\A#{URI::regexp(['http', 'https'])}\z/) ? "<a href='#{value}' target='blank'>#{value}</a>" : value
    
    {
      "key"=>field,
      "title_class"=>"technology-transfer-#{field.gsub('_','-')}-field",
      "value_class"=>"technology-transfer-#{field.gsub('_','-')}-value",
      "title"=>I18n.t('personal_technology_transfer.'+field),
      "value"=>value
    }
  end

end